==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/SecurityPolicyWebApplicationFirewallParametersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.SecurityPolicyWebApplicationFirewallParametersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The json object containing security policy waf parameters
 * @property associations Waf associations
 * @property type The type of the Security policy to create.
 * Expected value is 'WebApplicationFirewall'.
 * @property wafPolicy Resource ID.
 */
public data class SecurityPolicyWebApplicationFirewallParametersArgs(
    public val associations: Output<List<SecurityPolicyWebApplicationFirewallAssociationArgs>>? =
        null,
    public val type: Output<String>,
    public val wafPolicy: Output<ResourceReferenceArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.SecurityPolicyWebApplicationFirewallParametersArgs> {
    override fun toJava():
        com.pulumi.azurenative.cdn.inputs.SecurityPolicyWebApplicationFirewallParametersArgs =
        com.pulumi.azurenative.cdn.inputs.SecurityPolicyWebApplicationFirewallParametersArgs.builder()
            .associations(
                associations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .type(type.applyValue({ args0 -> args0 }))
            .wafPolicy(wafPolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [SecurityPolicyWebApplicationFirewallParametersArgs].
 */
@PulumiTagMarker
public class SecurityPolicyWebApplicationFirewallParametersArgsBuilder internal constructor() {
    private var associations: Output<List<SecurityPolicyWebApplicationFirewallAssociationArgs>>? =
        null

    private var type: Output<String>? = null

    private var wafPolicy: Output<ResourceReferenceArgs>? = null

    /**
     * @param value Waf associations
     */
    @JvmName("khrvfyrhxltccquk")
    public suspend
    fun associations(`value`: Output<List<SecurityPolicyWebApplicationFirewallAssociationArgs>>) {
        this.associations = value
    }

    @JvmName("kcsklxlsctiylhbu")
    public suspend fun associations(
        vararg
        values: Output<SecurityPolicyWebApplicationFirewallAssociationArgs>,
    ) {
        this.associations = Output.all(values.asList())
    }

    /**
     * @param values Waf associations
     */
    @JvmName("wbvpvxcvmgdjegag")
    public suspend
    fun associations(values: List<Output<SecurityPolicyWebApplicationFirewallAssociationArgs>>) {
        this.associations = Output.all(values)
    }

    /**
     * @param value The type of the Security policy to create.
     * Expected value is 'WebApplicationFirewall'.
     */
    @JvmName("ysempypqakelqbyn")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("lynumklyktmhtpnm")
    public suspend fun wafPolicy(`value`: Output<ResourceReferenceArgs>) {
        this.wafPolicy = value
    }

    /**
     * @param value Waf associations
     */
    @JvmName("vqgwhbykabrjvygt")
    public suspend
    fun associations(`value`: List<SecurityPolicyWebApplicationFirewallAssociationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.associations = mapped
    }

    /**
     * @param argument Waf associations
     */
    @JvmName("moceoojkjpuhqqtv")
    public suspend
    fun associations(argument: List<suspend SecurityPolicyWebApplicationFirewallAssociationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SecurityPolicyWebApplicationFirewallAssociationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.associations = mapped
    }

    /**
     * @param argument Waf associations
     */
    @JvmName("twrkeyobjwkafrcr")
    public suspend fun associations(
        vararg
        argument: suspend SecurityPolicyWebApplicationFirewallAssociationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            SecurityPolicyWebApplicationFirewallAssociationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.associations = mapped
    }

    /**
     * @param argument Waf associations
     */
    @JvmName("gruhylofbjxtctom")
    public suspend
    fun associations(argument: suspend SecurityPolicyWebApplicationFirewallAssociationArgsBuilder.() -> Unit) {
        val toBeMapped =
            listOf(
                SecurityPolicyWebApplicationFirewallAssociationArgsBuilder().applySuspend {
                    argument()
                }.build(),
            )
        val mapped = of(toBeMapped)
        this.associations = mapped
    }

    /**
     * @param values Waf associations
     */
    @JvmName("qpxqiqgemkyfvalu")
    public suspend fun associations(
        vararg
        values: SecurityPolicyWebApplicationFirewallAssociationArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.associations = mapped
    }

    /**
     * @param value The type of the Security policy to create.
     * Expected value is 'WebApplicationFirewall'.
     */
    @JvmName("yqicherssfacxros")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("wybqfssclvxqpcow")
    public suspend fun wafPolicy(`value`: ResourceReferenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.wafPolicy = mapped
    }

    /**
     * @param argument Resource ID.
     */
    @JvmName("dkribskqufkkxhfr")
    public suspend fun wafPolicy(argument: suspend ResourceReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = ResourceReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.wafPolicy = mapped
    }

    internal fun build(): SecurityPolicyWebApplicationFirewallParametersArgs =
        SecurityPolicyWebApplicationFirewallParametersArgs(
            associations = associations,
            type = type ?: throw PulumiNullFieldException("type"),
            wafPolicy = wafPolicy,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/SecurityPolicyWebApplicationFirewallParametersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.SecurityPolicyWebApplicationFirewallParametersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The json object containing security policy waf parameters
 * @property associations Waf associations
 * @property type The type of the Security policy to create.
 * Expected value is 'WebApplicationFirewall'.
 * @property wafPolicy Resource ID.
 */
public data class SecurityPolicyWebApplicationFirewallParametersArgs(
    public val associations: Output<List<SecurityPolicyWebApplicationFirewallAssociationArgs>>? =
        null,
    public val type: Output<String>,
    public val wafPolicy: Output<ResourceReferenceArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.SecurityPolicyWebApplicationFirewallParametersArgs> {
    override fun toJava():
        com.pulumi.azurenative.cdn.inputs.SecurityPolicyWebApplicationFirewallParametersArgs =
        com.pulumi.azurenative.cdn.inputs.SecurityPolicyWebApplicationFirewallParametersArgs.builder()
            .associations(
                associations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .type(type.applyValue({ args0 -> args0 }))
            .wafPolicy(wafPolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [SecurityPolicyWebApplicationFirewallParametersArgs].
 */
@PulumiTagMarker
public class SecurityPolicyWebApplicationFirewallParametersArgsBuilder internal constructor() {
    private var associations: Output<List<SecurityPolicyWebApplicationFirewallAssociationArgs>>? =
        null

    private var type: Output<String>? = null

    private var wafPolicy: Output<ResourceReferenceArgs>? = null

    /**
     * @param value Waf associations
     */
    @JvmName("ivpvbbauacacjyil")
    public suspend
    fun associations(`value`: Output<List<SecurityPolicyWebApplicationFirewallAssociationArgs>>) {
        this.associations = value
    }

    @JvmName("ttuttuhujogrsdvw")
    public suspend fun associations(
        vararg
        values: Output<SecurityPolicyWebApplicationFirewallAssociationArgs>,
    ) {
        this.associations = Output.all(values.asList())
    }

    /**
     * @param values Waf associations
     */
    @JvmName("jakmpiclaypqhkbg")
    public suspend
    fun associations(values: List<Output<SecurityPolicyWebApplicationFirewallAssociationArgs>>) {
        this.associations = Output.all(values)
    }

    /**
     * @param value The type of the Security policy to create.
     * Expected value is 'WebApplicationFirewall'.
     */
    @JvmName("fhbfowhtusqrigyc")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("tqkmexscesadcscu")
    public suspend fun wafPolicy(`value`: Output<ResourceReferenceArgs>) {
        this.wafPolicy = value
    }

    /**
     * @param value Waf associations
     */
    @JvmName("mgoncojisooruxvv")
    public suspend
    fun associations(`value`: List<SecurityPolicyWebApplicationFirewallAssociationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.associations = mapped
    }

    /**
     * @param argument Waf associations
     */
    @JvmName("hijojctrtbykbgeb")
    public suspend
    fun associations(argument: List<suspend SecurityPolicyWebApplicationFirewallAssociationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SecurityPolicyWebApplicationFirewallAssociationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.associations = mapped
    }

    /**
     * @param argument Waf associations
     */
    @JvmName("dpikmyuafyqbqyeg")
    public suspend fun associations(
        vararg
        argument: suspend SecurityPolicyWebApplicationFirewallAssociationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            SecurityPolicyWebApplicationFirewallAssociationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.associations = mapped
    }

    /**
     * @param argument Waf associations
     */
    @JvmName("njsnnnmtmcdhosll")
    public suspend
    fun associations(argument: suspend SecurityPolicyWebApplicationFirewallAssociationArgsBuilder.() -> Unit) {
        val toBeMapped =
            listOf(
                SecurityPolicyWebApplicationFirewallAssociationArgsBuilder().applySuspend {
                    argument()
                }.build(),
            )
        val mapped = of(toBeMapped)
        this.associations = mapped
    }

    /**
     * @param values Waf associations
     */
    @JvmName("xknkdmjuptamtjsa")
    public suspend fun associations(
        vararg
        values: SecurityPolicyWebApplicationFirewallAssociationArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.associations = mapped
    }

    /**
     * @param value The type of the Security policy to create.
     * Expected value is 'WebApplicationFirewall'.
     */
    @JvmName("qxrelrsrokbvgfmf")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("dmxnkaprdhujrpia")
    public suspend fun wafPolicy(`value`: ResourceReferenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.wafPolicy = mapped
    }

    /**
     * @param argument Resource ID.
     */
    @JvmName("jhdxvupdintqccpk")
    public suspend fun wafPolicy(argument: suspend ResourceReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = ResourceReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.wafPolicy = mapped
    }

    internal fun build(): SecurityPolicyWebApplicationFirewallParametersArgs =
        SecurityPolicyWebApplicationFirewallParametersArgs(
            associations = associations,
            type = type ?: throw PulumiNullFieldException("type"),
            wafPolicy = wafPolicy,
        )
}
